pub async fn event_log_commit_tree_file<F>(
    event_log_file: impl AsRef<Path>,
    verify: bool,
    func: F
) -> Result<CommitTree>
where F: Fn(&EventLogRecord),
Build a commit tree from a event log file optionally verifying all the row checksums.

The func is invoked with the row information so callers can display debugging information if necessary.