pub async fn vault_commit_tree_file<F>(
    vault: impl AsRef<Path>,
    verify: bool,
    func: F
) -> Result<CommitTree>
where F: Fn(&VaultRecord),
Build a commit tree from a vault file optionally verifying all the row checksums.

The func is invoked with the row information so callers can display debugging information if necessary.