pub enum Error {
Show 115 variants
PermissionDenied,
RpcRequestPayload,
RpcResponsePayload,
RpcError(String),
RpcUnknownMethod(String),
NotFile(PathBuf),
NoCache,
NotPassphraseEncryption,
NotRecipientEncryption,
NoRecipients,
NoSigner,
RecoveryThreshold(u8),
BadCipher(String, String),
NotDirectory(PathBuf),
InvalidKeyValue(String),
BadIdentity(u8),
IdentityLength,
UnknownCipher(u8),
InvalidCipher(String),
InvalidKeyDerivation(String),
UnknownSecretKind(u8),
UnknownEventKind(u16),
UnknownIdentityKind(u8),
UnknownSharedAccessKind(u8),
InvalidNonce,
NoChangeEvent,
VaultLocked,
SecretAlreadyExists(String),
SecretDoesNotExist(Uuid),
DicewareWordsTooFew(usize, u8),
PassphraseVerification,
NotIdentityVault,
NoSecretUrn(VaultId, Urn),
NoSecretId(VaultId, SecretId),
WrongSecretKind(VaultId, SecretId),
VaultNotInit,
VaultAlreadyInit,
UnknownKeyTypeId,
BadPublicKeyByte,
NotCompressedPublicKey,
InvalidChallengeResponse,
ChallengeNotFound,
InvalidPublicKeyLength(u8, usize),
BadAddressPrefix,
HashMismatch {
commit: String,
value: String,
},
CreateEventMustBeFirst,
CreateEventOnlyFirst,
NoRootCommit,
InvalidMethod(u16),
NotDigit,
InvalidVaultFlags,
InvalidSecretFlags,
UnknownPurpose(u8),
NoArchiveManifest,
NoArchiveVault(PathBuf),
ArchiveChecksumMismatch(String),
ZipDateTime,
AgeIdentityParse(String),
NoVaultEntry(String),
VaultEntryKind(String),
NoArchiveAccount(String),
ArchiveAccountAlreadyExists(String),
NoDefaultVault(String),
NoVaultFile(String),
NoAccount(String),
ArchiveAddressMismatch,
NoArchiveDefaultVault,
NoSession,
BadSessionIdentity,
NoSessionIdentity,
NoSessionSalt,
NoSessionSharedSecret,
NoSessionKey,
BadNonce,
NotEcdsaKey,
NotEd25519Key,
NotSymmetric,
NotAsymmetric,
InvalidX25519Identity(String),
AttachmentNotFound(SecretId),
Boxed(Box<dyn Error + Send + Sync>),
Io(Error),
Hex(FromHexError),
PasswordHash(Error),
ParseInt(ParseIntError),
UrlParse(ParseError),
Uuid(Error),
TryFromSlice(TryFromSliceError),
Elliptic(Error),
Merkle(Error),
Time(ComponentRange),
TimeFormat(Format),
TimeParse(Parse),
InvalidFormat(InvalidFormatDescription),
Pem(PemError),
Json(Error),
Address(Error),
ChaCha(Error),
Urn(Error),
Signature(SignatureError),
Zxcvbn(ZxcvbnError),
Zip(ZipError),
TryFromInt(TryFromIntError),
Ed25519(Error),
Base58(Error),
Sha2DigestLength(InvalidLength),
AgeEncrypt(EncryptError),
AgeDecrypt(DecryptError),
Walk(Error),
StripPrefix(StripPrefixError),
AppDirs(AppDirsError),
Join(JoinError),
Mpc(Error),
Snow(Error),
Vsss(String),
}Expand description
Error thrown by the core library.
Variants
PermissionDenied
Permission denied.
If a shared vault is set to private shared access and somebody other than the owner attempts to write to encrypt a shared entry this error is generated.
RpcRequestPayload
Expected a request payload.
RpcResponsePayload
Expected a response payload.
RpcError(String)
Error encapsulated in RPC messages.
RpcUnknownMethod(String)
Error generated when an RPC method is not supported.
NotFile(PathBuf)
Error generated when a path is not a file.
NoCache
Error generated if we could not determine a cache directory.
NotPassphraseEncryption
Error generated when decrypting via AGE and expecting passhrase based encryption.
NotRecipientEncryption
Error generated when decrypting via AGE and expecting recipient based encryption.
NoRecipients
Error generated attempting to encrypt asymmetrically without and recipients.
NoSigner
Error generated when a signing key is required.
RecoveryThreshold(u8)
Error generated when a recovery group threshold is too small.
BadCipher(String, String)
Error generated attempting to encrypt or decrypt with the wrong cipher.
NotDirectory(PathBuf)
Error generated when a directory is expected.
InvalidKeyValue(String)
Error generated when attempting to parse a key/value pair.
BadIdentity(u8)
Error generated when a vault identity byte is wrong.
IdentityLength
Error generated when a buffer used to read identity bytes is not long enough.
UnknownCipher(u8)
Error generated when a vault cipher identifier byte is wrong.
InvalidCipher(String)
Error generated when a vault cipher string identifier is wrong.
InvalidKeyDerivation(String)
Error generated when a vault key derivation function string identifier is wrong.
UnknownSecretKind(u8)
Error generated when the kind of a secret is unknown.
UnknownEventKind(u16)
Error generated when the kind identifier of an event is unknown.
UnknownIdentityKind(u8)
Error generated when the kind of an identification secret is unknown.
Error generated when the kind of a shared access variant is unknown.
InvalidNonce
Error generated when an AeadPack contains a nonce that is invalid for the decryption cipher.
NoChangeEvent
Error generated attempting to convert to a change event.
VaultLocked
Error generated when a vault is locked.
SecretAlreadyExists(String)
Error generated when a secret already exists with the given label.
SecretDoesNotExist(Uuid)
Error generated when a secret does not exist for an update operation.
DicewareWordsTooFew(usize, u8)
Error generated when secret meta data does not exist.
PassphraseVerification
Error generated when attempting to verify a password fails.
This can happen when calling verify() on a Vault or unlock()
on a Gatekeeper.
NotIdentityVault
Error generated when a login vault does not contain the identity bit flag.
NoSecretUrn(VaultId, Urn)
Error generated when a vault does not contain a secret by URN.
NoSecretId(VaultId, SecretId)
Error generated when a vault does not contain a secret by identifier.
WrongSecretKind(VaultId, SecretId)
Error generated when a secret is of the wrong kind.
VaultNotInit
Error generated when a vault has not been initialized (no encrypted meta data).
VaultAlreadyInit
Error generated attempting to a initialize a vault when it has already been initialized.
UnknownKeyTypeId
Error generated when the type identifier for a public key is unknown.
BadPublicKeyByte
Error generated when the leading byte for a compressed public key is invalid.
NotCompressedPublicKey
Error generated when a public key is not compressed.
InvalidChallengeResponse
Error generated when a response to a challenge is invalid.
ChallengeNotFound
Error generated when a challenge could not be found.
InvalidPublicKeyLength(u8, usize)
Error generated when a public key has the wrong length.
BadAddressPrefix
Error generated when an address has the wrong prefix.
HashMismatch
Error generated when event log row data does not match the commit hash.
CreateEventMustBeFirst
Error generated when a a event log file does not begin with a create vault event.
CreateEventOnlyFirst
Error generated when a event log create vault event is not the first record.
NoRootCommit
Error generated when a commit tree is expected to have a root.
InvalidMethod(u16)
Error generated when an RPC method kind is invalid.
NotDigit
Error generated when a value is expected to be all digits.
InvalidVaultFlags
Error generated when decoding vault flags has invalid bits.
InvalidSecretFlags
Error generated when decoding secret flags has invalid bits.
UnknownPurpose(u8)
Error generated when decoding a vault purpose identifier that is not known.
NoArchiveManifest
Error generated an archive does not contain a manifest file.
NoArchiveVault(PathBuf)
Error generated an archive does not contain a manifest file.
ArchiveChecksumMismatch(String)
Error generated an archive does not contain a manifest file.
ZipDateTime
Error generated converting now to the zip date time format.
AgeIdentityParse(String)
Error generated parsing an AGE identity from a string.
NoVaultEntry(String)
Error generated when a vault entry in the identity vault could not be located.
VaultEntryKind(String)
Error generated when a vault entry in an identity vault is of the wrong secret kind.
NoArchiveAccount(String)
Error generated when an archive is for an address that does not exist locally when we are expecting an archive to be imported in the context of an existing account.
ArchiveAccountAlreadyExists(String)
Error generated attempting to restore an account from an archive whilst not authenticated and the address for the archive matches an account that already exists.
NoDefaultVault(String)
Error generated when the default vault for an account could not be found.
NoVaultFile(String)
Error generated when a vault file could not be located.
NoAccount(String)
Error generated when an account does not exist.
ArchiveAddressMismatch
Error generated when an archive signing key address does not match the address in the archive manifest.
NoArchiveDefaultVault
Error generated when an archive does not contain a default vault.
NoSession
Error generated when a session does not exist.
BadSessionIdentity
Error generated when a session identity signature does not match the initial address.
NoSessionIdentity
Error generated when attempting to compute a shared secret before a session identity has been proven.
NoSessionSalt
Error generated when a session does not yet have a salt.
Error generated when a session shared secret has not yet been created.
NoSessionKey
Error generated when a session key does not exist.
BadNonce
Error generated when a session receives a nonce that is equal to or less than the current server session nonce.
NotEcdsaKey
Error generated when an ECDSA signing key is expected.
NotEd25519Key
Error generated when an Ed25519 signing key is expected.
NotSymmetric
Error generated when attempting to use an asymmetric private key with a symmetric cipher.
NotAsymmetric
Error generated when attempting to use a symmetric private key with an asymmetric cipher.
InvalidX25519Identity(String)
Error generated when attempting to parse an AGE identity.
AttachmentNotFound(SecretId)
Error generated when an attachment could not be found.
Boxed(Box<dyn Error + Send + Sync>)
Generic boxed error.
Io(Error)
Error generated by password hash.
Hex(FromHexError)
Error generated by password hash.
PasswordHash(Error)
Error generated by password hash.
ParseInt(ParseIntError)
Error generated parsing integers.
UrlParse(ParseError)
Error generated parsing URLs.
Uuid(Error)
Error generated parsing UUIDs.
TryFromSlice(TryFromSliceError)
Error generated converting to fixed length slice.
Elliptic(Error)
Error generated during AES encryption and decryption. Error generated by elliptic curve library.
Merkle(Error)
Error generated by the merkle tree library.
Time(ComponentRange)
Error generated converting time types.
TimeFormat(Format)
Error generated formatting time.
TimeParse(Parse)
Error generated parsing time.
InvalidFormat(InvalidFormatDescription)
Error generated creating format descriptions for date formatting.
Pem(PemError)
Error generated parsing PEM files.
Json(Error)
Error generated by the JSON library.
Address(Error)
Error generated by the address library.
ChaCha(Error)
Error generated by the crypto library.
Urn(Error)
Error generated by the URN library.
Signature(SignatureError)
Error generated by the signature library.
Zxcvbn(ZxcvbnError)
Error generated by the password entropy library.
Zip(ZipError)
Error generated by the async zip library.
TryFromInt(TryFromIntError)
Error generated when converting integers.
Ed25519(Error)
Error generated by the Ed25519 library.
Base58(Error)
Error generated by the Base58 library.
Sha2DigestLength(InvalidLength)
Error generated by the SHA2 library.
AgeEncrypt(EncryptError)
Error generated by the AGE library when encrypting.
AgeDecrypt(DecryptError)
Error generated by the AGE library when decrypting.
Walk(Error)
Error generated when walking a directory.
StripPrefix(StripPrefixError)
Error generated when stripping a prefix from a path.
AppDirs(AppDirsError)
Error generated when determining application paths.
Join(JoinError)
Error generated when attempting to join a task.
Mpc(Error)
Error generated by the MPC protocol library.
Snow(Error)
Error generated by the noise protocol library.
Vsss(String)
Error generated by verifiable secret sharing library.