Enum FileContent

pub enum FileContent {
    Embedded {
        name: String,
        mime: String,
        buffer: SecretBox<Vec<u8>>,
        checksum: [u8; 32],
    },
    External {
        name: String,
        mime: String,
        checksum: [u8; 32],
        size: u64,
        path: Option<PathBuf>,
    },
}
Variants for embedded and external file secrets.

Variants



Embedded

Embedded file buffer.

Fields

name: String

File name.

mime: String

Mime type for the data.

Use application/octet-stream if no mime-type is available.

buffer: SecretBox<Vec<u8>>

The binary data.

checksum: [u8; 32]

The SHA-256 digest of the buffer.

Using the SHA-256 digest allows the checksum to be computed using the Javascript SubtleCrypto API and in Dart using the crypto package.

This is used primarily during the public migration export to identify files that have been extracted to another location in the archive rather than embedding the binary data.



External

Encrypted data is stored in an external file.

Fields

name: String

File name.

mime: String

Mime type for the data.

Use application/octet-stream if no mime-type is available.

checksum: [u8; 32]

The SHA-256 digest of the buffer.

Using the SHA-256 digest allows the checksum to be computed using the Javascript SubtleCrypto API and in Dart using the crypto package.

This is used primarily during the public migration export to identify files that have been extracted to another location in the archive rather than embedding the binary data.

size: u64

Size of the encrypted file content.

path: Option<PathBuf>

Optional path to a source file; never encoded or serialized.

Implementations

Source

impl FileContent

pub fn name(&self) -> &str

File name.

pub fn mime(&self) -> &str

File mime type.

pub fn checksum(&self) -> &[u8; 32]

File checksum.

pub fn size(&self) -> u64

File size.