pub enum WriteEvent {
CreateVault(Vec<u8>),
SetVaultName(String),
SetVaultFlags(VaultFlags),
SetVaultMeta(AeadPack),
CreateSecret(Uuid, VaultCommit),
UpdateSecret(Uuid, VaultCommit),
DeleteSecret(Uuid),
// some variants omitted
}Expand description
Write operations.
Variants
CreateVault(Vec<u8>)
Event used to indicate a vault was created.
The buffer is the initial state of the vault, if the vault contains secrets they should be separated using an FolderReducer::split beforehand and appended to the event log as create secret events.
SetVaultName(String)
Event used to indicate the vault name was set.
SetVaultFlags(VaultFlags)
Event used to indicate the vault flags were set.
SetVaultMeta(AeadPack)
Event used to indicate the vault meta data was set.
CreateSecret(Uuid, VaultCommit)
Event used to indicate a secret was created.
UpdateSecret(Uuid, VaultCommit)
Event used to indicate a secret was updated.
DeleteSecret(Uuid)
Event used to indicate a secret was deleted.