pub struct Diff<T> {
pub patch: Patch<T>,
pub checkpoint: CommitProof,
pub last_commit: Option<CommitHash>,
}Expand description
Diff between local and remote.
Fields
patch: Patch<T>Contents of the patch.
checkpoint: CommitProofCheckpoint for the diff patch.
For checked patches this must match the proof of HEAD before the patch was created.
For unchecked force merges this checkpoint references the commit proof of HEAD after applying the patch.
last_commit: Option<CommitHash>Last commit hash before the patch was created.
This can be used to determine if the patch is to be used to initialize a new set of events when no last commit is available.
For example, for file event logs which are lazily instantiated once external files are created.
Implementations
Sourceimpl<T> Diff<T>
impl<T> Diff<T>
Sourcepub fn new(
patch: Patch<T>,
checkpoint: CommitProof,
last_commit: Option<CommitHash>,
) -> Diff<T>
pub fn new( patch: Patch<T>, checkpoint: CommitProof, last_commit: Option<CommitHash>, ) -> Diff<T>
Create a diff.