Struct DeviceManager

pub struct DeviceManager { /* private fields */ }
Manages the access point that protects the device signing key.

Call DeviceManager::sign_out to lock the device vault.

Implementations

Source

impl DeviceManager

pub async fn new( target: &BackendTarget, account_id: &AccountId, signer: DeviceSigner, password: &AccessKey, ) -> Result<DeviceManager, Error>

Create a new device manager from a signer.

pub async fn open_vault( target: BackendTarget, vault: Vault, access_key: &AccessKey, ) -> Result<(DeviceManager, Uuid), Error>

Load a device manager from an existing vault.

pub async fn into_vault_buffer(self) -> Result<Vec<u8>, Error>

Consume this device manager into a buffer of the vault.

pub fn current_device( &self, extra_info: Option<DeviceMetaData>, ) -> TrustedDevice

Current device information.

pub fn sign_out(&mut self)

Sign out locking the device vault.