pub struct Header { /* private fields */ }Expand description
File header, identifier and version information
Implementations
Sourceimpl Header
impl Header
Sourcepub fn new(
id: Uuid,
name: String,
cipher: Cipher,
kdf: KeyDerivation,
flags: VaultFlags,
) -> Header
pub fn new( id: Uuid, name: String, cipher: Cipher, kdf: KeyDerivation, flags: VaultFlags, ) -> Header
Create a new header.
Sourcepub fn flags(&self) -> &VaultFlags
pub fn flags(&self) -> &VaultFlags
Reference to the vault flags.
Sourcepub fn flags_mut(&mut self) -> &mut VaultFlags
pub fn flags_mut(&mut self) -> &mut VaultFlags
Mutable reference to the vault flags.
Sourcepub async fn read_content_offset<P>(path: P) -> Result<u64, Error>
pub async fn read_content_offset<P>(path: P) -> Result<u64, Error>
Read the content offset for a vault file verifying the identity bytes first.
Sourcepub async fn read_content_offset_slice(buffer: &[u8]) -> Result<u64, Error>
pub async fn read_content_offset_slice(buffer: &[u8]) -> Result<u64, Error>
Read the content offset for a vault slice verifying the identity bytes first.
Sourcepub async fn read_content_offset_stream<R>(stream: R) -> Result<u64, Error>
pub async fn read_content_offset_stream<R>(stream: R) -> Result<u64, Error>
Read the content offset for a stream verifying the identity bytes first.
Sourcepub async fn read_summary_file<P>(file: P) -> Result<Summary, Error>
pub async fn read_summary_file<P>(file: P) -> Result<Summary, Error>
Read the summary for a vault from a file.