Create and compare commits in an underlying merkle tree.
Structs
- Hash representation that provides a hexadecimal display.
- Represents a root hash and a proof of certain nodes.
- Commit state combines the last commit hash with a commit proof.
- Encapsulates a Merkle tree and provides functions for generating and comparing proofs.
Enums
- The result of comparing two commit trees.
Constants
- Commit hash of zeroes.
Functions
- Build a commit tree from a event log file optionally verifying all the row checksums.
- Build a commit tree from a vault file optionally verifying all the row checksums.