pub enum FileContent {
Embedded {
name: String,
mime: String,
buffer: SecretBox<Vec<u8>>,
checksum: [u8; 32],
},
External {
name: String,
mime: String,
checksum: [u8; 32],
size: u64,
path: Option<PathBuf>,
},
}Expand description
Variants for embedded and external file secrets.
Variants
Embedded
Embedded file buffer.
Fields
checksum: [u8; 32]The SHA-256 digest of the buffer.
Using the SHA-256 digest allows the checksum to be computed using the Javascript SubtleCrypto API and in Dart using the crypto package.
This is used primarily during the public migration export to identify files that have been extracted to another location in the archive rather than embedding the binary data.
External
Encrypted data is stored in an external file.
Fields
checksum: [u8; 32]The SHA-256 digest of the buffer.
Using the SHA-256 digest allows the checksum to be computed using the Javascript SubtleCrypto API and in Dart using the crypto package.
This is used primarily during the public migration export to identify files that have been extracted to another location in the archive rather than embedding the binary data.
Implementations