pub type AccountDiff = Diff<AccountEvent>;Expand description
Diff between account events logs.
Aliased Type
pub struct AccountDiff {
pub patch: Patch<AccountEvent>,
pub checkpoint: CommitProof,
pub last_commit: Option<CommitHash>,
}Fields
patch: Patch<AccountEvent>Contents of the patch.
checkpoint: CommitProofCheckpoint for the diff patch.
For checked patches this must match the proof of HEAD before the patch was created.
For unchecked force merges this checkpoint references the commit proof of HEAD after applying the patch.
last_commit: Option<CommitHash>Last commit hash before the patch was created.
This can be used to determine if the patch is to be used to initialize a new set of events when no last commit is available.
For example, for file event logs which are lazily instantiated once external files are created.