pub struct DeviceManager { /* private fields */ }Expand description
Manages the access point that protects the device signing key.
Call DeviceManager::sign_out to lock the device vault.
Implementations
Sourceimpl DeviceManager
impl DeviceManager
Sourcepub async fn new(
target: &BackendTarget,
account_id: &AccountId,
signer: DeviceSigner,
password: &AccessKey,
) -> Result<DeviceManager, Error>
pub async fn new( target: &BackendTarget, account_id: &AccountId, signer: DeviceSigner, password: &AccessKey, ) -> Result<DeviceManager, Error>
Create a new device manager from a signer.
Sourcepub async fn open_vault(
target: BackendTarget,
vault: Vault,
access_key: &AccessKey,
) -> Result<(DeviceManager, Uuid), Error>
pub async fn open_vault( target: BackendTarget, vault: Vault, access_key: &AccessKey, ) -> Result<(DeviceManager, Uuid), Error>
Load a device manager from an existing vault.
Sourcepub async fn into_vault_buffer(self) -> Result<Vec<u8>, Error>
pub async fn into_vault_buffer(self) -> Result<Vec<u8>, Error>
Consume this device manager into a buffer of the vault.
Sourcepub fn current_device(
&self,
extra_info: Option<DeviceMetaData>,
) -> TrustedDevice
pub fn current_device( &self, extra_info: Option<DeviceMetaData>, ) -> TrustedDevice
Current device information.